Learn R Programming

EcoTroph (version 1.6.1)

saturation: Sigma Saturation Function

Description

This function enables an other calculation for the sigma of the create.smooth function. Sigma is calculated on the base of a saturation function reflecting a biological reasoning about the variability of the TL within trophic classes: the variability increases with the TL and reaches a plateau after a certain TL.

Usage

saturation(sigma_inf = NULL, coeff = NULL, pas = NULL)

Arguments

sigma_inf

defines the value of the curve's plateau.

coeff

defines the value of the slope.

pas

defines the splitting of the TL classes.

Value

saturation returns a vector of values for the sigma used in the create.smooth function.

Details

By default sigma is constant. This function enables an other user choice reflecting a different reasoning.

See Also

create.smooth function to create the Smooth, plot.smooth to plot the smooth function.

Examples

Run this code
# NOT RUN {
plot(saturation())
lines(saturation(0.2))
text(48,0.18,"sigma_inf=0.2")
lines(saturation(coeff=0.5))
text(48,0.35,"coeff=0.5")
# }

Run the code above in your browser using DataLab